==> pim-data-exporter_20.08.3.orig.tar.xz: pim-data-exporter-20.08.3/core/autotests/generatelistfilefromarchive.cpp <==
/*
   Copyright (C) 2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "generatelistfilefromarchive.h"
#include "core/utils.h"
#include <KZip>
#include <QTest>

GenerateListFileFromArchive::GenerateListFileFromArchive(const QString &fileName)
    : mFileName(fileName)
{
    generateList();
}

GenerateListFileFromArchive::~GenerateListFileFromArchive()
{
    delete mZip;
    mZip = nullptr;
}

void GenerateListFileFromArchive::generateList()
{
    mZip = new KZip(mFileName);
    //qDebug() << " mFileName" << mFileName;
    bool result = mZip->open(QIODevice::ReadOnly);
    QVERIFY(result);
    const KArchiveDirectory *topDirectory = mZip->directory();
    const bool isAValidArchive = searchArchiveElement(Utils::infoPath(), topDirectory);
    QVERIFY(isAValidArchive);
    (void)searchArchiveElement(Utils::mailsPath(), topDirectory);
    (void)searchArchiveElement(Utils::alarmPath(), topDirectory);
    (void)searchArchiveElement(Utils::calendarPath(), topDirectory);
    (void)searchArchiveElement(Utils::addressbookPath(), topDirectory);
    (void)searchArchiveElement(Utils::identitiesPath(), topDirectory);
    (void)searchArchiveElement(Utils::resourcesPath(), topDirectory);
    (void)searchArchiveElement(Utils::configsPath(), topDirectory);
    (void)searchArchiveElement(Utils::transportsPath(), topDirectory);
    (void)searchArchiveElement(Utils::dataPath(), topDirectory);
    (void)searchArchiveElement(Utils::notePath(), topDirectory);
    mListFile.sort();
}

QStringList GenerateListFileFromArchive::listFile() const
{
    return mListFile;
}

bool GenerateListFileFromArchive::searchArchiveElement(const QString &path, const KArchiveDirectory *topDirectory)
{
    const KArchiveEntry *topEntry = topDirectory->entry(path);
    bool result = true;
    if (topEntry) {
        addSubItems(path, topEntry, 0);
    } else {
        result = false;
    }
    return result;
}

void GenerateListFileFromArchive::addSubItems(const QString &topLevelPath, const KArchiveEntry *entry, int indent, const QString &fullpath)
{
    const KArchiveDirectory *dir = static_cast<const KArchiveDirectory *>(entry);
    const QString space = QString(indent * 2, QLatin1Char(' '));
    const QStringList lst = dir->entries();
    for (const QString &entryName : lst) {
        const KArchiveEntry *entry = dir->entry(entryName);
        if (entry) {
            if (entry->isDirectory()) {
                const KArchiveDirectory *dirEntry = static_cast<const KArchiveDirectory *>(entry);
                //mListFile += space + dirEntry->name();
                addSubItems(topLevelPath, entry, indent, (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + dirEntry->name());
            } else if (entry->isFile()) {
                const KArchiveFile *file = static_cast<const KArchiveFile *>(entry);
                const QString fileFullPath = topLevelPath + (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + file->name();
                mListFile += space + fileFullPath;
            }
        }
    }
}

==> pim-data-exporter-20.12.1.tar.xz: pim-data-exporter-20.12.1/core/autotests/generatelistfilefromarchive.cpp <==
/*
   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "generatelistfilefromarchive.h"
#include "core/utils.h"
#include <KZip>
#include <QTest>

GenerateListFileFromArchive::GenerateListFileFromArchive(const QString &fileName)
    : mFileName(fileName)
{
    generateList();
}

GenerateListFileFromArchive::~GenerateListFileFromArchive()
{
    delete mZip;
    mZip = nullptr;
}

void GenerateListFileFromArchive::generateList()
{
    mZip = new KZip(mFileName);
    //qDebug() << " mFileName" << mFileName;
    bool result = mZip->open(QIODevice::ReadOnly);
    QVERIFY(result);
    const KArchiveDirectory *topDirectory = mZip->directory();
    const bool isAValidArchive = searchArchiveElement(Utils::infoPath(), topDirectory);
    QVERIFY(isAValidArchive);
    (void)searchArchiveElement(Utils::mailsPath(), topDirectory);
    (void)searchArchiveElement(Utils::alarmPath(), topDirectory);
    (void)searchArchiveElement(Utils::calendarPath(), topDirectory);
    (void)searchArchiveElement(Utils::addressbookPath(), topDirectory);
    (void)searchArchiveElement(Utils::identitiesPath(), topDirectory);
    (void)searchArchiveElement(Utils::resourcesPath(), topDirectory);
    (void)searchArchiveElement(Utils::configsPath(), topDirectory);
    (void)searchArchiveElement(Utils::transportsPath(), topDirectory);
    (void)searchArchiveElement(Utils::dataPath(), topDirectory);
    (void)searchArchiveElement(Utils::notePath(), topDirectory);
    mListFile.sort();
}

QStringList GenerateListFileFromArchive::listFile() const
{
    return mListFile;
}

bool GenerateListFileFromArchive::searchArchiveElement(const QString &path, const KArchiveDirectory *topDirectory)
{
    const KArchiveEntry *topEntry = topDirectory->entry(path);
    bool result = true;
    if (topEntry) {
        addSubItems(path, topEntry, 0);
    } else {
        result = false;
    }
    return result;
}

void GenerateListFileFromArchive::addSubItems(const QString &topLevelPath, const KArchiveEntry *entry, int indent, const QString &fullpath)
{
    const auto *dir = static_cast<const KArchiveDirectory *>(entry);
    const QString space = QString(indent * 2, QLatin1Char(' '));
    const QStringList lst = dir->entries();
    for (const QString &entryName : lst) {
        const KArchiveEntry *entry = dir->entry(entryName);
        if (entry) {
            if (entry->isDirectory()) {
                const auto *dirEntry = static_cast<const KArchiveDirectory *>(entry);
                //mListFile += space + dirEntry->name();
                addSubItems(topLevelPath, entry, indent, (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + dirEntry->name());
            } else if (entry->isFile()) {
                const auto *file = static_cast<const KArchiveFile *>(entry);
                const QString fileFullPath = topLevelPath + (fullpath.isEmpty() ? QString() : fullpath + QLatin1Char('/')) + file->name();
                mListFile += space + fileFullPath;
            }
        }
    }
}
